@@ -6,12 +6,13 @@
 
 __author__ = """luphord"""
 __email__ = """luphord@protonmail.com"""
-__version__ = """0.6.0"""
+__version__ = """0.7.0"""
 
 
 import sys
 import os
 import urllib
+import math
 from argparse import ArgumentParser, Namespace, ArgumentDefaultsHelpFormatter
 from pathlib import Path
 from xml.etree import ElementTree
@@ -62,6 +63,9 @@ class Catalog:
         for file_path in self.files:
             yield file_path
 
+    def __len__(self):
+        return len(self.files)
+
     def check(self):
         missing = list(self.missing_files())
         if missing:
@@ -75,11 +79,16 @@ class Catalog:
             file_element.attrib["uri"] = file_path.as_uri()
         return ElementTree.ElementTree(xml)
 
-    def create_symlinks(self, directory, force_override=False):
+    def create_symlinks(self, directory, force_override=False, index_prefix=False):
         """Create symlinks to all files in catalog in `directory`"""
-        for file_path in self:
+        ndigits = math.ceil(math.log10(len(self)))
+        index_fmt = "{:0" + str(ndigits) + "d}_{}"
+        for i, file_path in enumerate(self):
             os.makedirs(directory, exist_ok=True)
-            link_path = directory / file_path.name
+            fname = (
+                index_fmt.format(i, file_path.name) if index_prefix else file_path.name
+            )
+            link_path = directory / fname
             if force_override and link_path.exists():
                 link_path.unlink()
             os.symlink(file_path.absolute(), link_path)
@@ -93,6 +102,10 @@ class Catalog:
 
     @staticmethod
     def load_from_file(fname):
+        if Path(fname).stat().st_size == 0:
+            # pix creates empty catalog files initially, i.e. xml is invalid
+            # and loading it needs to be handled as a special case
+            return Catalog([])
         xml = ElementTree.parse(fname)
         return Catalog.load_from_xml(xml)
 
@@ -195,6 +208,13 @@ symlink_parser.add_argument(
     default=False,
     action="store_true",
 )
+symlink_parser.add_argument(
+    "-i",
+    "--index-prefix",
+    help="Prefix the link file name with the image index, e.g. 123_fname.jpg",
+    default=False,
+    action="store_true",
+)
 symlink_parser.add_argument(
     "-d",
     "--directory-structure",
@@ -214,7 +234,7 @@ def _symlink(args: Namespace) -> None:
             ).with_suffix("")
         else:
             output_path = output_base
-        catalog.create_symlinks(output_path, args.force_override)
+        catalog.create_symlinks(output_path, args.force_override, args.index_prefix)
 
 
 symlink_parser.set_defaults(func=_symlink)
